pub fn global_config_path(ctx: &ConfigContext) -> Option<PathBuf>Expand description
Configuration loading and schema helpers. Return the global configuration file path, if it can be determined.
pub fn global_config_path(ctx: &ConfigContext) -> Option<PathBuf>Configuration loading and schema helpers. Return the global configuration file path, if it can be determined.